@@ -16,11 +16,9 @@ class Serializer(object):
         """
         Deserialize a str item from redis into a Python object.
 
-        Args:
-            str_from_redis (str): the str corresponding with an item in redis
-
-        Returns:
-            object.
+        :param str_from_redis: the str corresponding with an item in redis
+        :type str_from_redis: str
+        :returns: object
 
         """
 
@@ -29,11 +27,8 @@ class Serializer(object):
         """
         Serialize a Python object into a `str`
 
-        Args:
-            obj (object): the Python object to be stored in a sorted set
-
-        Returns:
-            str.
+        :param obj: the Python object to be stored in a sorted set
+        :returns: str
 
         """
 
